@@ -14,7 +14,7 @@
  */
 #include <debug_ll.h>
 #include <common.h>
-#include <sizes.h>
+#include <linux/sizes.h>
 #include <io.h>
 #include <asm/barebox-arm-head.h>
 #include <asm/barebox-arm.h>
