@@ -25,10 +25,12 @@
 #define IMX_SSP3_BASE		0x80016000
 #define IMX_IOMUXC_BASE		0x80018000
 #define IMX_DIGCTL_BASE		0x8001c000
+#define IMX_EMI_BASE		0x80020000
 #define IMX_OCOTP_BASE		0x8002c000
 #define IMX_FB_BASE		0x80030000
 #define IMX_CCM_BASE		0x80040000
 #define IMX_POWER_BASE		0x80044000
+#define IMX_LRADC_BASE		0x80050000
 #define IMX_WDT_BASE		0x80056000
 #define IMX_I2C0_BASE		0x80058000
 #define IMX_I2C1_BASE		0x8005a000
@@ -43,6 +45,7 @@
 #define IMX_USBPHY1_BASE	0x8007e000
 #define IMX_USB0_BASE		0x80080000
 #define IMX_USB1_BASE		0x80090000
+#define IMX_SDRAMC_BASE		0x800e0000
 #define IMX_FEC0_BASE		0x800F0000
 #define IMX_FEC1_BASE		0x800F4000
 
