@@ -3,6 +3,8 @@
 
 #include <fdt.h>
 #include <errno.h>
+#include <linux/types.h>
+#include <linux/list.h>
 #include <asm/byteorder.h>
 
 /* Default string compare functions */
@@ -35,7 +37,7 @@ struct device_node {
 
 struct of_device_id {
 	char *compatible;
-	unsigned long data;
+	const void *data;
 };
 
 #define MAX_PHANDLE_ARGS 8
@@ -238,7 +240,8 @@ int of_add_memory(struct device_node *node, bool dump);
 void of_add_memory_bank(struct device_node *node, bool dump, int r,
 		u64 base, u64 size);
 struct device_d *of_find_device_by_node_path(const char *path);
-int of_find_path(struct device_node *node, const char *propname, char **outpath);
+#define OF_FIND_PATH_FLAGS_BB 1		/* return .bb device if available */
+int of_find_path(struct device_node *node, const char *propname, char **outpath, unsigned flags);
 int of_register_fixup(int (*fixup)(struct device_node *, void *), void *context);
 struct device_node *of_find_node_by_alias(struct device_node *root,
 		const char *alias);
